@@ -1,18 +1,22 @@
 /*
   ==============================================================================
 
-   This file is part of the JUCE examples.
-   Copyright (c) 2022 - Raw Material Software Limited
+   This file is part of the JUCE framework examples.
+   Copyright (c) Raw Material Software Limited
 
    The code included in this file is provided under the terms of the ISC license
    http://www.isc.org/downloads/software-support-policy/isc-license. Permission
-   To use, copy, modify, and/or distribute this software for any purpose with or
+   to use, copy, modify, and/or distribute this software for any purpose with or
    without fee is hereby granted provided that the above copyright notice and
    this permission notice appear in all copies.
 
-   THE SOFTWARE IS PROVIDED "AS IS" WITHOUT ANY WARRANTY, AND ALL WARRANTIES,
-   WHETHER EXPRESSED OR IMPLIED, INCLUDING MERCHANTABILITY AND FITNESS FOR
-   PURPOSE, ARE DISCLAIMED.
+   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
+   REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
+   AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
+   INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
+   LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
+   OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
+   PERFORMANCE OF THIS SOFTWARE.
 
   ==============================================================================
 */
@@ -54,7 +58,7 @@
     is enabled. It contains an icon that can be used to show the side panel containing
     the menu.
 */
-struct BurgerMenuHeader  : public Component
+struct BurgerMenuHeader final : public Component
 {
     BurgerMenuHeader (SidePanel& sp)
         : sidePanel (sp)
@@ -102,7 +106,7 @@ private:
 
         burgerButton.setBounds (r.removeFromRight (40).withSizeKeepingCentre (20, 20));
 
-        titleLabel.setFont (Font ((float) getHeight() * 0.5f, Font::plain));
+        titleLabel.setFont (FontOptions ((float) getHeight() * 0.5f, Font::plain));
         titleLabel.setBounds (r);
     }
 
@@ -120,9 +124,9 @@ private:
 };
 
 //==============================================================================
-class MenusDemo    : public Component,
-                     public ApplicationCommandTarget,
-                     public MenuBarModel
+class MenusDemo final : public Component,
+                        public ApplicationCommandTarget,
+                        public MenuBarModel
 {
 public:
     //==============================================================================
@@ -341,8 +345,8 @@ private:
         Command messages that aren't handled in the main component will be passed
         to this class to respond to.
     */
-    class OuterCommandTarget    : public Component,
-                                  public ApplicationCommandTarget
+    class OuterCommandTarget final : public Component,
+                                     public ApplicationCommandTarget
     {
     public:
         OuterCommandTarget (ApplicationCommandManager& m)
@@ -430,8 +434,8 @@ private:
             Command messages that aren't handled in the OuterCommandTarget will be passed
             to this class to respond to.
         */
-        struct InnerCommandTarget    : public Component,
-                                       public ApplicationCommandTarget
+        struct InnerCommandTarget final : public Component,
+                                          public ApplicationCommandTarget
         {
             InnerCommandTarget (ApplicationCommandManager& m)
                 : commandManager (m)
