@@ -1,18 +1,22 @@
 /*
   ==============================================================================
 
-   This file is part of the JUCE examples.
-   Copyright (c) 2022 - Raw Material Software Limited
+   This file is part of the JUCE framework examples.
+   Copyright (c) Raw Material Software Limited
 
    The code included in this file is provided under the terms of the ISC license
    http://www.isc.org/downloads/software-support-policy/isc-license. Permission
-   To use, copy, modify, and/or distribute this software for any purpose with or
+   to use, copy, modify, and/or distribute this software for any purpose with or
    without fee is hereby granted provided that the above copyright notice and
    this permission notice appear in all copies.
 
-   THE SOFTWARE IS PROVIDED "AS IS" WITHOUT ANY WARRANTY, AND ALL WARRANTIES,
-   WHETHER EXPRESSED OR IMPLIED, INCLUDING MERCHANTABILITY AND FITNESS FOR
-   PURPOSE, ARE DISCLAIMED.
+   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
+   REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
+   AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
+   INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
+   LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
+   OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
+   PERFORMANCE OF THIS SOFTWARE.
 
   ==============================================================================
 */
@@ -51,9 +55,9 @@
 #if JUCE_MAC || JUCE_WINDOWS
 //==============================================================================
 // so that we can easily have two video windows each with a file browser, wrap this up as a class..
-class MovieComponentWithFileBrowser  : public Component,
-                                       public DragAndDropTarget,
-                                       private FilenameComponentListener
+class MovieComponentWithFileBrowser final : public Component,
+                                            public DragAndDropTarget,
+                                            private FilenameComponentListener
 {
 public:
     MovieComponentWithFileBrowser()
@@ -134,19 +138,22 @@ private:
         }
         else
         {
-            AlertWindow::showMessageBoxAsync (MessageBoxIconType::WarningIcon,
-                                              "Couldn't load the file!",
-                                              result.getErrorMessage());
+            auto options = MessageBoxOptions::makeOptionsOk (MessageBoxIconType::WarningIcon,
+                                                             "Couldn't load the file!",
+                                                             result.getErrorMessage());
+            messageBox = AlertWindow::showScopedAsync (options, nullptr);
         }
     }
 
+    ScopedMessageBox messageBox;
+
     JUCE_DECLARE_NON_COPYABLE_WITH_LEAK_DETECTOR (MovieComponentWithFileBrowser)
 };
 
 //==============================================================================
-class VideoDemo   : public Component,
-                    public DragAndDropContainer,
-                    private FileBrowserListener
+class VideoDemo final : public Component,
+                        public DragAndDropContainer,
+                        private FileBrowserListener
 {
 public:
     VideoDemo()
@@ -266,8 +273,8 @@ private:
 };
 #elif JUCE_IOS || JUCE_ANDROID
 //==============================================================================
-class VideoDemo   : public Component,
-                    private Timer
+class VideoDemo final : public Component,
+                        private Timer
 {
 public:
     VideoDemo()
@@ -540,7 +547,7 @@ private:
 
             curVideoComp->onPlaybackStarted = [this]() { processPlaybackStarted(); };
             curVideoComp->onPlaybackStopped = [this]() { processPlaybackPaused(); };
-            curVideoComp->onErrorOccurred   = [this](const String& errorMessage) { errorOccurred (errorMessage); };
+            curVideoComp->onErrorOccurred   = [this] (const String& errorMessage) { errorOccurred (errorMessage); };
             curVideoComp->setVisible (true);
 
            #if JUCE_SYNC_VIDEO_VOLUME_WITH_OS_MEDIA_VOLUME
@@ -627,7 +634,7 @@ private:
         currentPositionLabel.setText (getPositionString (position, duration), sendNotification);
 
         if (! positionSliderDragging)
-            positionSlider.setValue (duration != 0 ? (position / duration) : 0.0, dontSendNotification);
+            positionSlider.setValue (approximatelyEqual (duration, 0.0) ? 0.0 : (position / duration), dontSendNotification);
     }
 
     void seekVideoToStart()
