@@ -1,18 +1,22 @@
 /*
   ==============================================================================
 
-   This file is part of the JUCE examples.
-   Copyright (c) 2022 - Raw Material Software Limited
+   This file is part of the JUCE framework examples.
+   Copyright (c) Raw Material Software Limited
 
    The code included in this file is provided under the terms of the ISC license
    http://www.isc.org/downloads/software-support-policy/isc-license. Permission
-   To use, copy, modify, and/or distribute this software for any purpose with or
+   to use, copy, modify, and/or distribute this software for any purpose with or
    without fee is hereby granted provided that the above copyright notice and
    this permission notice appear in all copies.
 
-   THE SOFTWARE IS PROVIDED "AS IS" WITHOUT ANY WARRANTY, AND ALL WARRANTIES,
-   WHETHER EXPRESSED OR IMPLIED, INCLUDING MERCHANTABILITY AND FITNESS FOR
-   PURPOSE, ARE DISCLAIMED.
+   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
+   REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
+   AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
+   INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
+   LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
+   OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
+   PERFORMANCE OF THIS SOFTWARE.
 
   ==============================================================================
 */
@@ -54,7 +58,7 @@
 #include "../Assets/DemoUtilities.h"
 
 //==============================================================================
-class MaterialLookAndFeel : public LookAndFeel_V4
+class MaterialLookAndFeel final : public LookAndFeel_V4
 {
 public:
     //==============================================================================
@@ -106,12 +110,12 @@ public:
     //==============================================================================
     void drawLinearSlider (Graphics& g, int x, int y, int width, int height,
                            float sliderPos, float minSliderPos, float maxSliderPos,
-                           const Slider::SliderStyle style, Slider& slider) override
+                           Slider::SliderStyle style, Slider& slider) override
     {
         ignoreUnused (style, minSliderPos, maxSliderPos);
 
         auto r = Rectangle<int> (x + haloRadius, y, width - (haloRadius * 2), height);
-        auto backgroundBar = r.withSizeKeepingCentre(r.getWidth(), 2);
+        auto backgroundBar = r.withSizeKeepingCentre (r.getWidth(), 2);
 
         sliderPos = (sliderPos - minSliderPos) / static_cast<float> (width);
 
@@ -178,8 +182,8 @@ public:
 };
 
 //==============================================================================
-class AUv3SynthEditor   : public AudioProcessorEditor,
-                          private Timer
+class AUv3SynthEditor final : public AudioProcessorEditor,
+                              private Timer
 {
 public:
     //==============================================================================
@@ -309,10 +313,10 @@ private:
 };
 
 //==============================================================================
-class AUv3SynthProcessor : public AudioProcessor
+class AUv3SynthProcessor final : public AudioProcessor
 {
 public:
-    AUv3SynthProcessor ()
+    AUv3SynthProcessor()
         : AudioProcessor (BusesProperties().withOutput ("Output", AudioChannelSet::stereo(), true)),
           currentRecording (1, 1), currentProgram (0)
     {
