@@ -1,18 +1,22 @@
 /*
   ==============================================================================
 
-   This file is part of the JUCE examples.
-   Copyright (c) 2022 - Raw Material Software Limited
+   This file is part of the JUCE framework examples.
+   Copyright (c) Raw Material Software Limited
 
    The code included in this file is provided under the terms of the ISC license
    http://www.isc.org/downloads/software-support-policy/isc-license. Permission
-   To use, copy, modify, and/or distribute this software for any purpose with or
+   to use, copy, modify, and/or distribute this software for any purpose with or
    without fee is hereby granted provided that the above copyright notice and
    this permission notice appear in all copies.
 
-   THE SOFTWARE IS PROVIDED "AS IS" WITHOUT ANY WARRANTY, AND ALL WARRANTIES,
-   WHETHER EXPRESSED OR IMPLIED, INCLUDING MERCHANTABILITY AND FITNESS FOR
-   PURPOSE, ARE DISCLAIMED.
+   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
+   REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
+   AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
+   INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
+   LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
+   OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
+   PERFORMANCE OF THIS SOFTWARE.
 
   ==============================================================================
 */
@@ -67,7 +71,7 @@
 */
 
 //==============================================================================
-class VoicePurchases      : private InAppPurchases::Listener
+class VoicePurchases final : private InAppPurchases::Listener
 {
 public:
     //==============================================================================
@@ -156,12 +160,13 @@ private:
                 voiceProduct.purchasePrice = "In-App purchases unavailable";
             }
 
-            AlertWindow::showMessageBoxAsync (MessageBoxIconType::WarningIcon,
-                                              "In-app purchase is unavailable!",
-                                              "In-App purchases are not available. This either means you are trying "
-                                              "to use IAP on a platform that does not support IAP or you haven't setup "
-                                              "your app correctly to work with IAP.",
-                                              "OK");
+            auto options = MessageBoxOptions::makeOptionsOk (MessageBoxIconType::WarningIcon,
+                                                             "In-app purchase is unavailable!",
+                                                             "In-App purchases are not available. This either means you are trying "
+                                                             "to use IAP on a platform that does not support IAP or you haven't setup "
+                                                             "your app correctly to work with IAP.",
+                                                             "OK");
+            messageBox = AlertWindow::showScopedAsync (options, nullptr);
         }
         else
         {
@@ -178,17 +183,18 @@ private:
                 }
             }
 
-            AlertWindow::showMessageBoxAsync (MessageBoxIconType::WarningIcon,
-                                              "Your credit card will be charged!",
-                                              "You are running the sample code for JUCE In-App purchases. "
-                                              "Although this is only sample code, it will still CHARGE YOUR CREDIT CARD!",
-                                              "Understood!");
+            auto options = MessageBoxOptions::makeOptionsOk (MessageBoxIconType::WarningIcon,
+                                                             "Your credit card will be charged!",
+                                                             "You are running the sample code for JUCE In-App purchases. "
+                                                             "Although this is only sample code, it will still CHARGE YOUR CREDIT CARD!",
+                                                             "Understood!");
+            messageBox = AlertWindow::showScopedAsync (options, nullptr);
         }
 
         guiUpdater.triggerAsyncUpdate();
     }
 
-    void productPurchaseFinished (const PurchaseInfo& info, bool success, const String&) override
+    void productPurchaseFinished (const PurchaseInfo& info, bool success, const String& error) override
     {
         purchaseInProgress = false;
 
@@ -211,6 +217,12 @@ private:
             }
         }
 
+        if (! success)
+        {
+            auto options = MessageBoxOptions::makeOptionsOk (MessageBoxIconType::WarningIcon, "Purchase failed", error);
+            messageBox = AlertWindow::showScopedAsync (options, nullptr);
+        }
+
         guiUpdater.triggerAsyncUpdate();
     }
 
@@ -264,12 +276,13 @@ private:
     AsyncUpdater& guiUpdater;
     bool havePurchasesBeenRestored = false, havePricesBeenFetched = false, purchaseInProgress = false;
     Array<VoiceProduct> voiceProducts;
+    ScopedMessageBox messageBox;
 
     JUCE_DECLARE_NON_COPYABLE_WITH_LEAK_DETECTOR (VoicePurchases)
 };
 
 //==============================================================================
-class PhraseModel : public ListBoxModel
+class PhraseModel final : public ListBoxModel
 {
 public:
     PhraseModel() {}
@@ -299,12 +312,12 @@ private:
 };
 
 //==============================================================================
-class VoiceModel  : public ListBoxModel
+class VoiceModel final : public ListBoxModel
 {
 public:
     //==============================================================================
-    class VoiceRow  : public Component,
-                      private Timer
+    class VoiceRow final : public Component,
+                           private Timer
     {
     public:
         VoiceRow (VoicePurchases& voicePurchases) : purchases (voicePurchases)
@@ -382,10 +395,10 @@ public:
                 else
                     stopTimer();
 
-                nameLabel.setFont (Font (16).withStyle (Font::bold | (hasBeenPurchased ? 0 : Font::italic)));
+                nameLabel.setFont (FontOptions { 16.0f, Font::bold | (hasBeenPurchased ? 0 : Font::italic) });
                 nameLabel.setColour (Label::textColourId, hasBeenPurchased ? Colours::white : Colours::grey);
 
-                priceLabel.setFont (Font (10).withStyle (purchase.priceIsKnown ? 0 : Font::italic));
+                priceLabel.setFont (FontOptions { 10.0f, purchase.priceIsKnown ? 0 : Font::italic });
                 priceLabel.setColour (Label::textColourId, hasBeenPurchased ? Colours::white : Colours::grey);
                 priceLabel.setText (purchase.purchasePrice, NotificationType::dontSendNotification);
 
@@ -482,8 +495,8 @@ private:
 };
 
 //==============================================================================
-class InAppPurchasesDemo : public Component,
-                           private AsyncUpdater
+class InAppPurchasesDemo final : public Component,
+                                 private AsyncUpdater
 {
 public:
     InAppPurchasesDemo()
