@@ -1,24 +1,33 @@
 /*
   ==============================================================================
 
-   This file is part of the JUCE library.
-   Copyright (c) 2022 - Raw Material Software Limited
+   This file is part of the JUCE framework.
+   Copyright (c) Raw Material Software Limited
 
-   JUCE is an open source library subject to commercial or open-source
+   JUCE is an open source framework subject to commercial or open source
    licensing.
 
-   By using JUCE, you agree to the terms of both the JUCE 7 End-User License
-   Agreement and JUCE Privacy Policy.
+   By downloading, installing, or using the JUCE framework, or combining the
+   JUCE framework with any other source code, object code, content or any other
+   copyrightable work, you agree to the terms of the JUCE End User Licence
+   Agreement, and all incorporated terms including the JUCE Privacy Policy and
+   the JUCE Website Terms of Service, as applicable, which will bind you. If you
+   do not agree to the terms of these agreements, we will not license the JUCE
+   framework to you, and you must discontinue the installation or download
+   process and cease use of the JUCE framework.
 
-   End User License Agreement: www.juce.com/juce-7-licence
-   Privacy Policy: www.juce.com/juce-privacy-policy
+   JUCE End User Licence Agreement: https://juce.com/legal/juce-8-licence/
+   JUCE Privacy Policy: https://juce.com/juce-privacy-policy
+   JUCE Website Terms of Service: https://juce.com/juce-website-terms-of-service/
 
-   Or: You may also use this code under the terms of the GPL v3 (see
-   www.gnu.org/licenses).
+   Or:
 
-   JUCE IS PROVIDED "AS IS" WITHOUT ANY WARRANTY, AND ALL WARRANTIES, WHETHER
-   EXPRESSED OR IMPLIED, INCLUDING MERCHANTABILITY AND FITNESS FOR PURPOSE, ARE
-   DISCLAIMED.
+   You may also use this code under the terms of the AGPLv3:
+   https://www.gnu.org/licenses/agpl-3.0.en.html
+
+   THE JUCE FRAMEWORK IS PROVIDED "AS IS" WITHOUT ANY WARRANTY, AND ALL
+   WARRANTIES, WHETHER EXPRESSED OR IMPLIED, INCLUDING WARRANTY OF
+   MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, ARE DISCLAIMED.
 
   ==============================================================================
 */
@@ -242,7 +251,7 @@ private:
             for (int i = 0; i < cg.getNumColours(); ++i)
             {
                 out.writeDouble (cg.getColourPosition (i));
-                out.writeInt ((int) cg.getColour(i).getARGB());
+                out.writeInt ((int) cg.getColour (i).getARGB());
             }
         }
         else
@@ -289,7 +298,7 @@ private:
 };
 
 //==============================================================================
-class CanvasGeneratingContext    : public LowLevelGraphicsContext
+class CanvasGeneratingContext final : public LowLevelGraphicsContext
 {
 public:
     CanvasGeneratingContext (SharedCanvasDescription& c)  : canvas (c)
@@ -298,9 +307,10 @@ public:
     }
 
     //==============================================================================
-    bool isVectorDevice() const override            { return true; }
-    float getPhysicalPixelScaleFactor() override    { return 1.0f; }
-    void setOrigin (Point<int> o) override          { addTransform (AffineTransform::translation ((float) o.x, (float) o.y)); }
+    bool isVectorDevice() const override               { return true; }
+    float getPhysicalPixelScaleFactor() const override { return 1.0f; }
+    uint64_t getFrameId() const override               { return 0; }
+    void setOrigin (Point<int> o) override             { addTransform (AffineTransform::translation ((float) o.x, (float) o.y)); }
 
     void addTransform (const AffineTransform& t) override
     {
@@ -395,17 +405,33 @@ public:
     const Font& getFont() override                  { return getState().font; }
     void setFont (const Font& newFont) override     { getState().font = newFont; }
 
-    void drawGlyph (int glyphNumber, const AffineTransform& transform) override
+    void drawGlyphs (Span<const uint16_t> indices,
+                     Span<const Point<float>> positions,
+                     const AffineTransform& transform) override
     {
-        Path p;
-        Font& font = getState().font;
-        font.getTypefacePtr()->getOutlineForGlyph (glyphNumber, p);
-        fillPath (p, AffineTransform::scale (font.getHeight() * font.getHorizontalScale(), font.getHeight()).followedBy (transform));
+        std::unordered_map<uint16_t, Path> cache;
+
+        const auto& font = getState().font;
+
+        for (size_t i = 0; i < indices.size(); i++)
+        {
+            const auto glyphNumber = indices[i];
+            const auto pos         = positions[i];
+            auto& path             = cache[glyphNumber];
+
+            if (path.isEmpty())
+                font.getTypefacePtr()->getOutlineForGlyph (TypefaceMetricsKind::legacy, glyphNumber, path);
+
+            auto t = AffineTransform::scale (font.getHeight() * font.getHorizontalScale(), font.getHeight())
+                                     .followedBy (AffineTransform::translation (pos))
+                                     .followedBy (transform);
+            fillPath (path, t);
+        }
     }
 
 private:
     //==============================================================================
-    struct SharedCanvasHolder  : public ReferenceCountedObject
+    struct SharedCanvasHolder final : public ReferenceCountedObject
     {
         SharedCanvasDescription canvas;
     };
@@ -414,7 +440,7 @@ private:
     {
         FillType fillType;
         AffineTransform transform;
-        Font font;
+        Font font { FontOptions{} };
         ReferenceCountedObjectPtr<SharedCanvasHolder> transparencyLayer;
         float transparencyOpacity = 1.0f;
     };
@@ -467,7 +493,7 @@ struct BlockPacketiser
         for (int i = 0; i < blocks.size(); ++i)
         {
             auto index = (uint32) ByteOrder::swapIfBigEndian (i);
-            blocks.getReference(i).append (&index, sizeof (index));
+            blocks.getReference (i).append (&index, sizeof (index));
         }
     }
 
@@ -487,7 +513,7 @@ struct BlockPacketiser
         if (blocks.size() > 1)
         {
             for (int i = 0; i < blocks.size() - 1; ++i)
-                result.append (blocks.getReference(i).getData(), blocks.getReference(i).getSize() - 4);
+                result.append (blocks.getReference (i).getData(), blocks.getReference (i).getSize() - 4);
 
             String storedMD5 (String (CharPointer_ASCII ((const char*) blocks.getLast().getData()))
                                 .fromFirstOccurrenceOf (getLastPacketPrefix(), false, false));
