@@ -1,24 +1,33 @@
 /*
   ==============================================================================
 
-   This file is part of the JUCE library.
-   Copyright (c) 2022 - Raw Material Software Limited
+   This file is part of the JUCE framework.
+   Copyright (c) Raw Material Software Limited
 
-   JUCE is an open source library subject to commercial or open-source
+   JUCE is an open source framework subject to commercial or open source
    licensing.
 
-   By using JUCE, you agree to the terms of both the JUCE 7 End-User License
-   Agreement and JUCE Privacy Policy.
+   By downloading, installing, or using the JUCE framework, or combining the
+   JUCE framework with any other source code, object code, content or any other
+   copyrightable work, you agree to the terms of the JUCE End User Licence
+   Agreement, and all incorporated terms including the JUCE Privacy Policy and
+   the JUCE Website Terms of Service, as applicable, which will bind you. If you
+   do not agree to the terms of these agreements, we will not license the JUCE
+   framework to you, and you must discontinue the installation or download
+   process and cease use of the JUCE framework.
 
-   End User License Agreement: www.juce.com/juce-7-licence
-   Privacy Policy: www.juce.com/juce-privacy-policy
+   JUCE End User Licence Agreement: https://juce.com/legal/juce-8-licence/
+   JUCE Privacy Policy: https://juce.com/juce-privacy-policy
+   JUCE Website Terms of Service: https://juce.com/juce-website-terms-of-service/
 
-   Or: You may also use this code under the terms of the GPL v3 (see
-   www.gnu.org/licenses).
+   Or:
 
-   JUCE IS PROVIDED "AS IS" WITHOUT ANY WARRANTY, AND ALL WARRANTIES, WHETHER
-   EXPRESSED OR IMPLIED, INCLUDING MERCHANTABILITY AND FITNESS FOR PURPOSE, ARE
-   DISCLAIMED.
+   You may also use this code under the terms of the AGPLv3:
+   https://www.gnu.org/licenses/agpl-3.0.en.html
+
+   THE JUCE FRAMEWORK IS PROVIDED "AS IS" WITHOUT ANY WARRANTY, AND ALL
+   WARRANTIES, WHETHER EXPRESSED OR IMPLIED, INCLUDING WARRANTY OF
+   MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, ARE DISCLAIMED.
 
   ==============================================================================
 */
@@ -29,8 +38,8 @@
 #include "../../Application/jucer_Application.h"
 
 //==============================================================================
-class MessagesPopupWindow  : public Component,
-                             private ComponentMovementWatcher
+class MessagesPopupWindow final : public Component,
+                                  private ComponentMovementWatcher
 {
 public:
     MessagesPopupWindow (Component& target, Component& parent, Project& project)
@@ -95,9 +104,9 @@ public:
 
 private:
     //==============================================================================
-    class MessagesListComponent  : public Component,
-                                   private ValueTree::Listener,
-                                   private AsyncUpdater
+    class MessagesListComponent final : public Component,
+                                        private ValueTree::Listener,
+                                        private AsyncUpdater
     {
     public:
         MessagesListComponent (MessagesPopupWindow& o, Project& currentProject)
@@ -151,7 +160,7 @@ private:
         static constexpr int messageSpacing = 2;
 
         //==============================================================================
-        struct MessageComponent  : public Component
+        struct MessageComponent final : public Component
         {
             MessageComponent (MessagesListComponent& listComponent,
                               const Identifier& messageToDisplay,
@@ -170,11 +179,11 @@ private:
                 icon = (ProjectMessages::getTypeForMessage (message) == ProjectMessages::Ids::warning ? getIcons().warning : getIcons().info);
 
                 messageTitleLabel.setText (ProjectMessages::getTitleForMessage (message), dontSendNotification);
-                messageTitleLabel.setFont (Font (11.0f).boldened());
+                messageTitleLabel.setFont (FontOptions { 11.0f, Font::bold });
                 addAndMakeVisible (messageTitleLabel);
 
                 messageDescriptionLabel.setText (ProjectMessages::getDescriptionForMessage (message), dontSendNotification);
-                messageDescriptionLabel.setFont (Font (11.0f));
+                messageDescriptionLabel.setFont (FontOptions (11.0f));
                 messageDescriptionLabel.setJustificationType (Justification::topLeft);
                 addAndMakeVisible (messageDescriptionLabel);
 
@@ -379,7 +388,7 @@ private:
 };
 
 //==============================================================================
-class ProjectMessagesComponent  : public Component
+class ProjectMessagesComponent final : public Component
 {
 public:
     ProjectMessagesComponent()
@@ -492,8 +501,8 @@ public:
 
 private:
     //==============================================================================
-    struct MessageCountComponent  : public Component,
-                                    private ValueTree::Listener
+    struct MessageCountComponent final : public Component,
+                                         private ValueTree::Listener
     {
         MessageCountComponent (ProjectMessagesComponent& o, Path pathToUse)
           : owner (o),
