@@ -40,7 +40,6 @@
 #include "jucer_ProjectExport_MSVC.h"
 #include "jucer_ProjectExport_Xcode.h"
 #include "jucer_ProjectExport_Android.h"
-#include "jucer_ProjectExport_CodeBlocks.h"
 
 #include "../Utility/UI/PropertyComponents/jucer_FilePathPropertyComponent.h"
 
@@ -56,6 +55,17 @@ static auto createIcon (const void* iconData, size_t iconDataSize)
     return image;
 }
 
+std::vector<PackageDependency> makePackageDependencies (const StringArray& dependencies)
+{
+    std::vector<PackageDependency> result;
+    result.reserve ((size_t) dependencies.size());
+    std::transform (dependencies.begin(),
+                    dependencies.end(),
+                    std::back_inserter (result),
+                    [] (auto& d) { return PackageDependency { d }; });
+    return result;
+}
+
 template <typename Exporter>
 static ProjectExporter::ExporterTypeInfo createExporterTypeInfo (const void* iconData, size_t iconDataSize)
 {
@@ -82,20 +92,10 @@ std::vector<ProjectExporter::ExporterTypeInfo> ProjectExporter::getExporterTypeI
 
         createExporterTypeInfo<MSVCProjectExporterVC2022> (export_visualStudio_svg, export_visualStudio_svgSize),
         createExporterTypeInfo<MSVCProjectExporterVC2019> (export_visualStudio_svg, export_visualStudio_svgSize),
-        createExporterTypeInfo<MSVCProjectExporterVC2017> (export_visualStudio_svg, export_visualStudio_svgSize),
 
         createExporterTypeInfo<MakefileProjectExporter> (export_linux_svg, export_linux_svgSize),
 
         createExporterTypeInfo<AndroidProjectExporter> (export_android_svg, export_android_svgSize),
-
-        { CodeBlocksProjectExporter::getValueTreeTypeNameWindows(),
-          CodeBlocksProjectExporter::getDisplayNameWindows(),
-          CodeBlocksProjectExporter::getTargetFolderNameWindows(),
-          createIcon (export_codeBlocks_svg, export_codeBlocks_svgSize) },
-        { CodeBlocksProjectExporter::getValueTreeTypeNameLinux(),
-          CodeBlocksProjectExporter::getDisplayNameLinux(),
-          CodeBlocksProjectExporter::getTargetFolderNameLinux(),
-          createIcon (export_codeBlocks_svg, export_codeBlocks_svgSize) }
     };
 
     return infos;
@@ -162,10 +162,8 @@ std::unique_ptr<ProjectExporter> ProjectExporter::createExporterFromSettings (Pr
                                 Tag<XcodeProjectExporter>{},
                                 Tag<MSVCProjectExporterVC2022>{},
                                 Tag<MSVCProjectExporterVC2019>{},
-                                Tag<MSVCProjectExporterVC2017>{},
                                 Tag<MakefileProjectExporter>{},
-                                Tag<AndroidProjectExporter>{},
-                                Tag<CodeBlocksProjectExporter>{});
+                                Tag<AndroidProjectExporter>{});
 }
 
 bool ProjectExporter::canProjectBeLaunched (Project* project)
@@ -180,7 +178,6 @@ bool ProjectExporter::canProjectBeLaunched (Project* project)
             #elif JUCE_WINDOWS
              MSVCProjectExporterVC2022::getValueTreeTypeName(),
              MSVCProjectExporterVC2019::getValueTreeTypeName(),
-             MSVCProjectExporterVC2017::getValueTreeTypeName(),
             #endif
              AndroidProjectExporter::getValueTreeTypeName()
         };
@@ -601,9 +598,10 @@ static bool isLoadCurlSymbolsLazilyEnabled (Project& project)
             && project.isConfigFlagEnabled ("JUCE_LOAD_CURL_SYMBOLS_LAZILY", false));
 }
 
-StringArray ProjectExporter::getLinuxPackages (PackageDependencyType type) const
+std::vector<PackageDependency> ProjectExporter::getLinuxPackages (PackageDependencyType type) const
 {
     auto packages = linuxPackages;
+    std::vector<PackageDependency> dependencies;
 
     // don't add libcurl if curl symbols are loaded at runtime
     if (isCurlEnabled (project) && ! isLoadCurlSymbolsLazilyEnabled (project))
@@ -611,14 +609,17 @@ StringArray ProjectExporter::getLinuxPackages (PackageDependencyType type) const
 
     if (isWebBrowserComponentEnabled (project) && type == PackageDependencyType::compile)
     {
-        packages.add ("webkit2gtk-4.0");
         packages.add ("gtk+-x11-3.0");
+        dependencies.push_back (PackageDependency { "webkit2gtk-4.1", "webkit2gtk-4.0" });
     }
 
     packages.removeEmptyStrings();
     packages.removeDuplicates (false);
 
-    return packages;
+    const auto simpleDependencies = makePackageDependencies (packages);
+    dependencies.insert (dependencies.end(), simpleDependencies.begin(), simpleDependencies.end());
+
+    return dependencies;
 }
 
 void ProjectExporter::addProjectPathToBuildPathList (StringArray& pathList,
@@ -762,8 +763,7 @@ static bool areCompatibleExporters (const ProjectExporter& p1, const ProjectExpo
     return (p1.isVisualStudio() && p2.isVisualStudio())
         || (p1.isXcode() && p2.isXcode())
         || (p1.isMakefile() && p2.isMakefile())
-        || (p1.isAndroidStudio() && p2.isAndroidStudio())
-        || (p1.isCodeBlocks() && p2.isCodeBlocks() && p1.isWindows() != p2.isLinux());
+        || (p1.isAndroidStudio() && p2.isAndroidStudio());
 }
 
 void ProjectExporter::createDefaultModulePaths()
@@ -954,6 +954,7 @@ ProjectExporter::BuildConfiguration::BuildConfiguration (Project& p, const Value
                                 "-Wno-maybe-uninitialized",
                                 "-Wredundant-decls",
                                 "-Wno-strict-overflow",
+                                "-Wno-multichar",
                                 "-Wshadow" });
 }
 
