@@ -63,7 +63,7 @@ class ScopedNoDenormals;
     @tags{Audio}
 */
 template <typename FloatType, typename CountType>
-struct FloatVectorOperationsBase
+struct JUCE_API FloatVectorOperationsBase
 {
     /** Clears a vector of floating point numbers. */
     static void JUCE_CALLTYPE clear (FloatType* dest, CountType numValues) noexcept;
