@@ -120,13 +120,7 @@ public:
     {
         using CallbackPtr = decltype (std::addressof (callback));
 
-       #if JUCE_MINGW
-        #define JUCE_MINGW_HIDDEN_VISIBILITY __attribute__ ((visibility ("hidden")))
-       #else
-        #define JUCE_MINGW_HIDDEN_VISIBILITY
-       #endif
-
-        struct JUCE_MINGW_HIDDEN_VISIBILITY Callback
+        struct Callback
         {
             Callback (BytestreamToUMPDispatcher& d, CallbackPtr c)
                 : dispatch (d), callbackPtr (c) {}
@@ -145,8 +139,6 @@ public:
             CallbackPtr callbackPtr = nullptr;
         };
 
-       #undef JUCE_MINGW_HIDDEN_VISIBILITY
-
         Callback inputCallback { *this, &callback };
         concatenator.pushMidiData (begin, int (end - begin), timestamp, (void*) nullptr, inputCallback);
     }
