@@ -37,10 +37,6 @@
 
 #if JucePlugin_Build_AUv3
 
-#if JUCE_MAC && ! (defined (MAC_OS_X_VERSION_10_11) && MAC_OS_X_VERSION_MIN_REQUIRED >= MAC_OS_X_VERSION_10_11)
- #error AUv3 needs Deployment Target OS X 10.11 or higher to compile
-#endif
-
 #ifndef __OBJC2__
  #error AUv3 needs Objective-C 2 support (compile with 64-bit)
 #endif
@@ -73,6 +69,24 @@
 
 #include <future>
 
+JUCE_BEGIN_IGNORE_WARNINGS_GCC_LIKE ("-Wfour-char-constants")
+inline constexpr auto pluginIsMidiEffect = JucePlugin_AUMainType == kAudioUnitType_MIDIProcessor;
+JUCE_END_IGNORE_WARNINGS_GCC_LIKE
+
+inline constexpr auto pluginProducesMidiOutput =
+#if JucePlugin_ProducesMidiOutput
+        true;
+#else
+        pluginIsMidiEffect;
+#endif
+
+inline constexpr auto pluginWantsMidiInput =
+#if JucePlugin_WantsMidiInput
+        true;
+#else
+        pluginIsMidiEffect;
+#endif
+
 JUCE_BEGIN_IGNORE_WARNINGS_GCC_LIKE ("-Wnullability-completeness")
 
 using namespace juce;
@@ -342,9 +356,12 @@ public:
 
     bool shouldChangeToFormat (AVAudioFormat* format, AUAudioUnitBus* auBus)
     {
-        const bool isInput = ([auBus busType] == AUAudioUnitBusTypeInput);
-        const int busIdx = static_cast<int> ([auBus index]);
-        const int newNumChannels = static_cast<int> ([format channelCount]);
+        if (allocated)
+            return false;
+
+        const auto isInput = ([auBus busType] == AUAudioUnitBusTypeInput);
+        const auto busIdx = static_cast<int> ([auBus index]);
+        const auto newNumChannels = static_cast<int> ([format channelCount]);
 
         AudioProcessor& processor = getAudioProcessor();
 
@@ -385,11 +402,7 @@ public:
     //==============================================================================
     int getVirtualMIDICableCount() const
     {
-       #if JucePlugin_WantsMidiInput
-        return 1;
-       #else
-        return 0;
-       #endif
+        return pluginWantsMidiInput;
     }
 
     bool getSupportsMPE() const
@@ -399,11 +412,10 @@ public:
 
     NSArray<NSString*>* getMIDIOutputNames() const
     {
-       #if JucePlugin_ProducesMidiOutput
-        return @[@"MIDI Out"];
-       #else
+        if constexpr (pluginProducesMidiOutput)
+            return @[@"MIDI Out"];
+
         return @[];
-       #endif
     }
 
     //==============================================================================
@@ -448,7 +460,7 @@ public:
         if (str != nullptr)
         {
             AudioProcessor::TrackProperties props;
-            props.name = nsStringToJuce (str);
+            props.name = std::make_optional (nsStringToJuce (str));
 
             getAudioProcessor().updateTrackProperties (props);
         }
@@ -457,6 +469,7 @@ public:
     //==============================================================================
     bool allocateRenderResourcesAndReturnError (NSError **outError)
     {
+        allocated = false;
         AudioProcessor& processor = getAudioProcessor();
         const AUAudioFrameCount maxFrames = [au maximumFramesToRender];
 
@@ -547,16 +560,23 @@ public:
         hostMusicalContextCallback = [au musicalContextBlock];
         hostTransportStateCallback = [au transportStateBlock];
 
-        if (@available (macOS 10.13, iOS 11.0, *))
+       #if JUCE_APPLE_MIDI_EVENT_LIST_SUPPORTED
+        if (@available (macOS 12, iOS 15, *))
+            eventListOutput.setBlock ([au MIDIOutputEventListBlock]);
+       #endif
+
+        if (@available (macOS 10.13, *))
             midiOutputEventBlock = [au MIDIOutputEventBlock];
 
         reset();
+        allocated = true;
 
         return true;
     }
 
     void deallocateRenderResources()
     {
+        allocated = false;
         midiOutputEventBlock = nullptr;
 
         hostMusicalContextCallback = nullptr;
@@ -633,7 +653,7 @@ public:
             {
                 const auto value = (newValue != nullptr ? *newValue : juceParam->getValue()) * getMaximumParameterValue (*juceParam);
 
-                if (@available (macOS 10.12, iOS 10.0, *))
+                if (@available (macOS 10.12, *))
                 {
                     [param setValue: value
                          originator: editorObserverToken.get()
@@ -752,7 +772,8 @@ public:
 private:
     struct Class final : public ObjCClass<AUAudioUnit>
     {
-        Class() : ObjCClass<AUAudioUnit> ("AUAudioUnit_")
+        Class()
+            : ObjCClass ("AUAudioUnit_")
         {
             addIvar<JuceAudioUnitv3*> ("cppObject");
 
@@ -853,7 +874,7 @@ private:
             addMethod (@selector (supportsMPE),                             [] (id self, SEL)                                                   { return _this (self)->getSupportsMPE() ? YES : NO; });
             JUCE_END_IGNORE_WARNINGS_GCC_LIKE
 
-            if (@available (macOS 10.13, iOS 11.0, *))
+            if (@available (macOS 10.13, *))
                 addMethod (@selector (MIDIOutputNames),                     [] (id self, SEL)                                                   { return _this (self)->getMIDIOutputNames(); });
 
             //==============================================================================
@@ -865,6 +886,7 @@ private:
             addMethod (@selector (setShouldBypassEffect:),                  [] (id self, SEL, BOOL shouldBypass)                                { return _this (self)->setShouldBypassEffect (shouldBypass); });
             addMethod (@selector (allocateRenderResourcesAndReturnError:),  [] (id self, SEL, NSError** error)                                  { return _this (self)->allocateRenderResourcesAndReturnError (error) ? YES : NO; });
             addMethod (@selector (deallocateRenderResources),               [] (id self, SEL)                                                   { return _this (self)->deallocateRenderResources(); });
+            addMethod (@selector (renderResourcesAllocated),                [] (id self, SEL)                                                   { return _this (self)->allocated; });
 
             //==============================================================================
             addMethod (@selector (contextName),                             [] (id self, SEL)                                                   { return _this (self)->getContextName(); });
@@ -875,7 +897,7 @@ private:
            #endif
 
             //==============================================================================
-            if (@available (macOS 10.13, iOS 11.0, *))
+            if (@available (macOS 10.13, *))
             {
                 addMethod (@selector (supportedViewConfigurations:), [] (id self, SEL, NSArray<AUAudioUnitViewConfiguration*>* configs)
                 {
@@ -1027,7 +1049,7 @@ private:
     class FactoryPresets
     {
     public:
-        using Presets = std::unique_ptr<NSMutableArray<AUAudioUnitPreset*>, NSObjectDeleter>;
+        using Presets = NSUniquePtr<NSMutableArray<AUAudioUnitPreset*>>;
 
         void set (Presets newPresets)
         {
@@ -1059,50 +1081,62 @@ private:
     //==============================================================================
     void addAudioUnitBusses (bool isInput)
     {
-        std::unique_ptr<NSMutableArray<AUAudioUnitBus*>, NSObjectDeleter> array ([[NSMutableArray<AUAudioUnitBus*> alloc] init]);
+        NSUniquePtr<NSMutableArray<AUAudioUnitBus*>> array ([[NSMutableArray<AUAudioUnitBus*> alloc] init]);
         AudioProcessor& processor = getAudioProcessor();
         const auto numWrapperBuses = AudioUnitHelpers::getBusCountForWrapper (processor, isInput);
         const auto numProcessorBuses = AudioUnitHelpers::getBusCount (processor, isInput);
 
         for (int i = 0; i < numWrapperBuses; ++i)
         {
-            using AVAudioFormatPtr = std::unique_ptr<AVAudioFormat, NSObjectDeleter>;
+            using AVAudioFormatPtr = NSUniquePtr<AVAudioFormat>;
 
-            const auto audioFormat = [&]() -> AVAudioFormatPtr
+            const auto audioFormat = [&]
             {
-                const auto tag = i < numProcessorBuses ? CoreAudioLayouts::toCoreAudio (processor.getChannelLayoutOfBus (isInput, i))
-                                                       : kAudioChannelLayoutTag_Stereo;
-                const std::unique_ptr<AVAudioChannelLayout, NSObjectDeleter> layout { [[AVAudioChannelLayout alloc] initWithLayoutTag: tag] };
+                const auto defaultLayout = i < numProcessorBuses ? processor.getBus (isInput, i)->getLastEnabledLayout()
+                                                                 : AudioChannelSet::stereo();
+                NSUniquePtr<AVAudioChannelLayout> layout { [[AVAudioChannelLayout alloc] initWithLayoutTag: CoreAudioLayouts::toCoreAudio (defaultLayout)] };
 
-                if (auto format = AVAudioFormatPtr { [[AVAudioFormat alloc] initStandardFormatWithSampleRate: kDefaultSampleRate
-                                                                                               channelLayout: layout.get()] })
+                if (AVAudioFormatPtr format { [[AVAudioFormat alloc] initStandardFormatWithSampleRate: kDefaultSampleRate
+                                                                                        channelLayout: layout.get()] })
                     return format;
 
-                const auto channels = i < numProcessorBuses ? processor.getChannelCountOfBus (isInput, i)
-                                                            : 2;
-
                 // According to the docs, this will fail if the number of channels is greater than 2.
-                if (auto format = AVAudioFormatPtr { [[AVAudioFormat alloc] initStandardFormatWithSampleRate: kDefaultSampleRate
-                                                                                                    channels: static_cast<AVAudioChannelCount> (channels)] })
+                if (AVAudioFormatPtr format { [[AVAudioFormat alloc] initStandardFormatWithSampleRate: kDefaultSampleRate
+                                                                                             channels: static_cast<AVAudioChannelCount> (defaultLayout.size())] })
                     return format;
 
                 jassertfalse;
-                return nullptr;
+                return AVAudioFormatPtr{};
             }();
 
-            using AUAudioUnitBusPtr = std::unique_ptr<AUAudioUnitBus, NSObjectDeleter>;
+            using AUAudioUnitBusPtr = NSUniquePtr<AUAudioUnitBus>;
 
-            const auto audioUnitBus = [&]() -> AUAudioUnitBusPtr
+            const auto audioUnitBus = [&]
             {
-                if (audioFormat != nullptr)
-                    return AUAudioUnitBusPtr { [[AUAudioUnitBus alloc] initWithFormat: audioFormat.get() error: nullptr] };
+                if (audioFormat == nullptr)
+                {
+                    jassertfalse;
+                    return AUAudioUnitBusPtr{};
+                }
 
-                jassertfalse;
-                return nullptr;
+                NSError* error = nullptr;
+                AUAudioUnitBusPtr result { [[AUAudioUnitBus alloc] initWithFormat: audioFormat.get() error: &error] };
+
+                if (error != nullptr)
+                {
+                    jassertfalse;
+                    return AUAudioUnitBusPtr{};
+                }
+
+                return result;
             }();
 
-            if (audioUnitBus != nullptr)
-                [array.get() addObject: audioUnitBus.get()];
+            if (audioUnitBus == nullptr)
+                continue;
+
+            const auto enabled = numProcessorBuses <= i || processor.getBus (isInput, i)->isEnabled();
+            [audioUnitBus.get() setEnabled: enabled];
+            [array.get() addObject: audioUnitBus.get()];
         }
 
         (isInput ? inputBusses : outputBusses).reset ([[AUAudioUnitBusArray alloc] initWithAudioUnit: au
@@ -1146,7 +1180,7 @@ private:
         if (parameter.isMetaParameter())
             flags |= kAudioUnitParameterFlag_IsGlobalMeta;
 
-        std::unique_ptr<NSMutableArray, NSObjectDeleter> valueStrings;
+        NSUniquePtr<NSMutableArray> valueStrings;
 
         // Is this a meter?
         if (((parameter.getCategory() & 0xffff0000) >> 16) == 2)
@@ -1187,7 +1221,7 @@ private:
             return String (parameter.getParameterIndex());
         };
 
-        std::unique_ptr<AUParameter, NSObjectDeleter> param;
+        NSUniquePtr<AUParameter> param;
 
         @try
         {
@@ -1218,9 +1252,9 @@ private:
 
     struct NodeArrayResult
     {
-        std::unique_ptr<NSMutableArray<AUParameterNode*>, NSObjectDeleter> nodeArray { [NSMutableArray<AUParameterNode*> new] };
+        NSUniquePtr<NSMutableArray<AUParameterNode*>> nodeArray { [NSMutableArray<AUParameterNode*> new] };
 
-        void addParameter (const AudioProcessorParameter&, std::unique_ptr<AUParameter, NSObjectDeleter> auParam)
+        void addParameter (const AudioProcessorParameter&, NSUniquePtr<AUParameter> auParam)
         {
             [nodeArray.get() addObject: [auParam.get() retain]];
         }
@@ -1248,7 +1282,7 @@ private:
         NodeArrayResult nodeArray;
         std::map<int, AUParameterAddress> addressForIndex;
 
-        void addParameter (const AudioProcessorParameter& juceParam, std::unique_ptr<AUParameter, NSObjectDeleter> auParam)
+        void addParameter (const AudioProcessorParameter& juceParam, NSUniquePtr<AUParameter> auParam)
         {
             const auto index = juceParam.getParameterIndex();
             const auto address = [auParam.get() address];
@@ -1347,7 +1381,7 @@ private:
        #endif
     }
 
-    void installNewParameterTree (std::unique_ptr<NSMutableArray<AUParameterNode*>, NSObjectDeleter> topLevelNodes)
+    void installNewParameterTree (NSUniquePtr<NSMutableArray<AUParameterNode*>> topLevelNodes)
     {
         editorObserverToken.reset();
 
@@ -1399,7 +1433,7 @@ private:
         {
             String name = getAudioProcessor().getProgramName (idx);
 
-            std::unique_ptr<AUAudioUnitPreset, NSObjectDeleter> preset ([[AUAudioUnitPreset alloc] init]);
+            NSUniquePtr<AUAudioUnitPreset> preset ([[AUAudioUnitPreset alloc] init]);
             [preset.get() setName: juceStringToNS (name)];
             [preset.get() setNumber: static_cast<NSInteger> (idx)];
 
@@ -1431,6 +1465,7 @@ private:
             switch (event->head.eventType)
             {
                 case AURenderEventMIDI:
+                case AURenderEventMIDISysEx:
                 {
                     const AUMIDIEvent& midiEvent = event->MIDI;
                     midiMessages.addEvent (midiEvent.data, midiEvent.length, static_cast<int> (midiEvent.eventSampleTime - startTime));
@@ -1471,10 +1506,6 @@ private:
                     }
                 }
                 break;
-
-                case AURenderEventMIDISysEx:
-                default:
-                    break;
             }
         }
     }
@@ -1583,19 +1614,7 @@ private:
             // process audio
             processBlock (audioBuffer.getBuffer (frameCount), midiMessages);
 
-            // send MIDI
-           #if JucePlugin_ProducesMidiOutput
-            if (@available (macOS 10.13, iOS 11.0, *))
-            {
-                if (auto midiOut = midiOutputEventBlock)
-                    for (const auto metadata : midiMessages)
-                        if (isPositiveAndBelow (metadata.samplePosition, frameCount))
-                            midiOut ((int64_t) metadata.samplePosition + (int64_t) (timestamp->mSampleTime + 0.5),
-                                     0,
-                                     metadata.numBytes,
-                                     metadata.data);
-            }
-           #endif
+            sendMidi ((int64_t) (timestamp->mSampleTime + 0.5), frameCount);
         }
 
         // copy back
@@ -1605,6 +1624,37 @@ private:
         return noErr;
     }
 
+    void sendMidi (int64_t baseTimeStamp, AUAudioFrameCount frameCount)
+    {
+        if constexpr (pluginProducesMidiOutput)
+        {
+            #if JUCE_APPLE_MIDI_EVENT_LIST_SUPPORTED
+             if (@available (macOS 12, iOS 15, *))
+             {
+                 if (eventListOutput.trySend (midiMessages, baseTimeStamp))
+                     return;
+             }
+            #endif
+
+            if (@available (macOS 10.13, *))
+            {
+                if (auto midiOut = midiOutputEventBlock)
+                {
+                    for (const auto metadata : midiMessages)
+                    {
+                        if (! isPositiveAndBelow (metadata.samplePosition, frameCount))
+                            continue;
+
+                        midiOut ((int64_t) metadata.samplePosition + baseTimeStamp,
+                                 0,
+                                 metadata.numBytes,
+                                 metadata.data);
+                    }
+                }
+            }
+        }
+    }
+
     void processBlock (juce::AudioBuffer<float>& buffer, MidiBuffer& midiBuffer) noexcept
     {
         auto& processor = getAudioProcessor();
@@ -1743,7 +1793,7 @@ private:
     int totalInChannels, totalOutChannels;
 
     CoreAudioTimeConversions timeConversions;
-    std::unique_ptr<AUAudioUnitBusArray, NSObjectDeleter> inputBusses, outputBusses;
+    NSUniquePtr<AUAudioUnitBusArray> inputBusses, outputBusses;
 
    #if ! JUCE_FORCE_USE_LEGACY_PARAM_IDS
     std::map<AUParameterAddress, int> indexForAddress;
@@ -1753,10 +1803,10 @@ private:
 
     // to avoid recursion on parameter changes, we need to add an
     // editor observer to do the parameter changes
-    std::unique_ptr<AUParameterTree, NSObjectDeleter> paramTree;
+    NSUniquePtr<AUParameterTree> paramTree;
     ObserverPtr editorObserverToken;
 
-    std::unique_ptr<NSMutableArray<NSNumber*>, NSObjectDeleter> channelCapabilities;
+    NSUniquePtr<NSMutableArray<NSNumber*>> channelCapabilities;
 
     FactoryPresets factoryPresets;
 
@@ -1771,6 +1821,7 @@ private:
     AUMIDIOutputEventBlock midiOutputEventBlock = nullptr;
 
    #if JUCE_APPLE_MIDI_EVENT_LIST_SUPPORTED
+    AudioUnitHelpers::EventListOutput eventListOutput;
     ump::ToBytestreamDispatcher converter { 2048 };
    #endif
 
@@ -1788,6 +1839,7 @@ private:
     static constexpr bool forceLegacyParamIDs = false;
    #endif
     AudioProcessorParameter* bypassParam = nullptr;
+    bool allocated = false;
 };
 
 #if JUCE_IOS
@@ -1805,7 +1857,7 @@ struct UIViewPeerControllerReceiver
 class JuceAUViewController
 {
 public:
-    JuceAUViewController (AUViewController<AUAudioUnitFactory>* p)
+    explicit JuceAUViewController (AUViewController<AUAudioUnitFactory>* p)
         : myself (p)
     {
         initialiseJuce_GUI();
