@@ -1,24 +1,33 @@
 /*
   ==============================================================================
 
-   This file is part of the JUCE library.
-   Copyright (c) 2022 - Raw Material Software Limited
+   This file is part of the JUCE framework.
+   Copyright (c) Raw Material Software Limited
 
-   JUCE is an open source library subject to commercial or open-source
+   JUCE is an open source framework subject to commercial or open source
    licensing.
 
-   By using JUCE, you agree to the terms of both the JUCE 7 End-User License
-   Agreement and JUCE Privacy Policy.
+   By downloading, installing, or using the JUCE framework, or combining the
+   JUCE framework with any other source code, object code, content or any other
+   copyrightable work, you agree to the terms of the JUCE End User Licence
+   Agreement, and all incorporated terms including the JUCE Privacy Policy and
+   the JUCE Website Terms of Service, as applicable, which will bind you. If you
+   do not agree to the terms of these agreements, we will not license the JUCE
+   framework to you, and you must discontinue the installation or download
+   process and cease use of the JUCE framework.
 
-   End User License Agreement: www.juce.com/juce-7-licence
-   Privacy Policy: www.juce.com/juce-privacy-policy
+   JUCE End User Licence Agreement: https://juce.com/legal/juce-8-licence/
+   JUCE Privacy Policy: https://juce.com/juce-privacy-policy
+   JUCE Website Terms of Service: https://juce.com/juce-website-terms-of-service/
 
-   Or: You may also use this code under the terms of the GPL v3 (see
-   www.gnu.org/licenses).
+   Or:
 
-   JUCE IS PROVIDED "AS IS" WITHOUT ANY WARRANTY, AND ALL WARRANTIES, WHETHER
-   EXPRESSED OR IMPLIED, INCLUDING MERCHANTABILITY AND FITNESS FOR PURPOSE, ARE
-   DISCLAIMED.
+   You may also use this code under the terms of the AGPLv3:
+   https://www.gnu.org/licenses/agpl-3.0.en.html
+
+   THE JUCE FRAMEWORK IS PROVIDED "AS IS" WITHOUT ANY WARRANTY, AND ALL
+   WARRANTIES, WHETHER EXPRESSED OR IMPLIED, INCLUDING WARRANTY OF
+   MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, ARE DISCLAIMED.
 
   ==============================================================================
 */
@@ -127,7 +136,7 @@ public:
             if (processor != nullptr)
             {
                 if (auto* bypassParam = processor->getBypassParameter())
-                    return (bypassParam->getValue() != 0.0f);
+                    return ! approximatelyEqual (bypassParam->getValue(), 0.0f);
             }
 
             return bypassed;
@@ -151,7 +160,7 @@ public:
 
         /** @internal
 
-            Returns true if setBypassed(true) was called on this node.
+            Returns true if setBypassed (true) was called on this node.
             This behaviour is different from isBypassed(), which may additionally return true if
             the node has a bypass parameter that is not set to 0.
         */
@@ -210,8 +219,11 @@ public:
     */
     enum class UpdateKind
     {
-        sync,   ///< Indicates that the graph should be rebuilt immediately after modification.
-        async   ///< Indicates that the graph rebuild should be deferred.
+        sync,   ///< Graph should be rebuilt immediately after modification.
+        async,  ///< Graph rebuild should be delayed. If you make several changes to the graph
+                ///< inside the same call stack, these changes will be applied in one go.
+        none    ///< Graph should not be rebuilt automatically. Use rebuild() to trigger a graph
+                ///< rebuild.
     };
 
     //==============================================================================
@@ -249,7 +261,7 @@ public:
 
         If this succeeds, it returns a pointer to the newly-created node.
     */
-    Node::Ptr addNode (std::unique_ptr<AudioProcessor> newProcessor, NodeID nodeId = {}, UpdateKind = UpdateKind::sync);
+    Node::Ptr addNode (std::unique_ptr<AudioProcessor> newProcessor, std::optional<NodeID> nodeId = std::nullopt, UpdateKind = UpdateKind::sync);
 
     /** Deletes a node within the graph which has the specified ID.
         This will also delete any connections that are attached to this node.
@@ -312,6 +324,14 @@ public:
     */
     bool removeIllegalConnections (UpdateKind = UpdateKind::sync);
 
+    /** Rebuilds the graph if necessary.
+
+        This function will only ever rebuild the graph on the main thread. If this function is
+        called from another thread, the rebuild request will be dispatched asynchronously to the
+        main thread.
+    */
+    void rebuild();
+
     //==============================================================================
     /** A special type of AudioProcessor that can live inside an AudioProcessorGraph
         in order to use the audio that comes into and out of the graph itself.
