@@ -190,9 +190,8 @@
 #include "time/juce_Time.cpp"
 #include "unit_tests/juce_UnitTest.cpp"
 #include "containers/juce_Variant.cpp"
-#include "javascript/juce_JSON.cpp"
-#include "javascript/juce_JSONUtils.cpp"
-#include "javascript/juce_Javascript.cpp"
+#include "json/juce_JSON.cpp"
+#include "json/juce_JSONUtils.cpp"
 #include "containers/juce_DynamicObject.cpp"
 #include "xml/juce_XmlDocument.cpp"
 #include "xml/juce_XmlElement.cpp"
@@ -226,6 +225,7 @@
  #include "native/juce_Registry_windows.cpp"
  #include "native/juce_SystemStats_windows.cpp"
  #include "native/juce_Threads_windows.cpp"
+ #include "native/juce_PlatformTimer_generic.cpp"
  #include "native/juce_PlatformTimer_windows.cpp"
 
 //==============================================================================
@@ -293,7 +293,7 @@
  #include "maths/juce_MathsFunctions_test.cpp"
  #include "misc/juce_EnumHelpers_test.cpp"
  #include "containers/juce_FixedSizeFunction_test.cpp"
- #include "javascript/juce_JSONSerialisation_test.cpp"
+ #include "json/juce_JSONSerialisation_test.cpp"
  #include "memory/juce_SharedResourcePointer_test.cpp"
  #include "text/juce_CharPointer_UTF8_test.cpp"
  #include "text/juce_CharPointer_UTF16_test.cpp"
