@@ -231,12 +231,10 @@ struct AndroidDocumentDetail
 
     struct DirectoryIteratorEngine
     {
-        JUCE_BEGIN_IGNORE_WARNINGS_GCC_LIKE ("-Wdeprecated-declarations")
-        JUCE_BEGIN_IGNORE_WARNINGS_MSVC (4996)
+        JUCE_BEGIN_IGNORE_DEPRECATION_WARNINGS
         DirectoryIteratorEngine (const File& dir, bool recursive)
             : iterator (dir, recursive, "*", File::findFilesAndDirectories) {}
-        JUCE_END_IGNORE_WARNINGS_MSVC
-        JUCE_END_IGNORE_WARNINGS_GCC_LIKE
+        JUCE_END_IGNORE_DEPRECATION_WARNINGS
 
         auto read() const { return AndroidDocument::fromFile (iterator.getFile()); }
         bool increment() { return iterator.next(); }
