@@ -359,45 +359,18 @@ private:
 
     static Array<File> getSecondaryStorageDirectories()
     {
+        auto* env = getEnv();
+        static jmethodID m = (env->GetMethodID (AndroidContext, "getExternalFilesDirs",
+                                                "(Ljava/lang/String;)[Ljava/io/File;"));
+        if (m == nullptr)
+            return {};
+
+        auto paths = convertFileArray (LocalRef<jobject> (env->CallObjectMethod (getAppContext().get(), m, nullptr)));
+
         Array<File> results;
 
-        if (getAndroidSDKVersion() >= 19)
-        {
-            auto* env = getEnv();
-            static jmethodID m = (env->GetMethodID (AndroidContext, "getExternalFilesDirs",
-                                                    "(Ljava/lang/String;)[Ljava/io/File;"));
-            if (m == nullptr)
-                return {};
-
-            auto paths = convertFileArray (LocalRef<jobject> (env->CallObjectMethod (getAppContext().get(), m, nullptr)));
-
-            for (auto path : paths)
-                results.add (getMountPointForFile (path));
-        }
-        else
-        {
-            // on older SDKs other external storages are located "next" to the primary
-            // storage mount point
-            auto mountFolder = getMountPointForFile (getPrimaryStorageDirectory())
-                                    .getParentDirectory();
-
-            // don't include every folder. Only folders which are actually mountpoints
-            juce_statStruct info;
-            if (! juce_stat (mountFolder.getFullPathName(), info))
-                return {};
-
-            auto rootFsDevice = info.st_dev;
-
-            for (const auto& iter : RangedDirectoryIterator (mountFolder, false, "*", File::findDirectories))
-            {
-                auto candidate = iter.getFile();
-
-                if (juce_stat (candidate.getFullPathName(), info)
-                      && info.st_dev != rootFsDevice)
-                    results.add (candidate);
-            }
-
-        }
+        for (auto path : paths)
+            results.add (getMountPointForFile (path));
 
         return results;
     }
@@ -587,8 +560,8 @@ struct AndroidStreamHelpers
 class AndroidInputStreamWrapper final : public InputStream
 {
 public:
-    explicit AndroidInputStreamWrapper (jobject streamIn)
-        : stream (LocalRef<jobject> { streamIn })
+    explicit AndroidInputStreamWrapper (LocalRef<jobject> streamIn)
+        : stream (std::move (streamIn))
     {
     }
 
@@ -604,7 +577,7 @@ public:
 
     AndroidInputStreamWrapper& operator= (AndroidInputStreamWrapper&& other) noexcept
     {
-        std::swap (*this, other);
+        AndroidInputStreamWrapper { std::move (other) }.swap (*this);
         return *this;
     }
 
@@ -612,6 +585,9 @@ public:
 
     ~AndroidInputStreamWrapper() override
     {
+        if (stream == nullptr)
+            return;
+
         getEnv()->CallVoidMethod (stream.get(), AndroidInputStream.close);
         jniCheckHasExceptionOccurredAndClear();
     }
@@ -674,14 +650,22 @@ private:
         return skipped == num;
     }
 
+    void swap (AndroidInputStreamWrapper& other) noexcept
+    {
+        std::swap (other.byteArray, byteArray);
+        std::swap (other.stream, stream);
+        std::swap (other.pos, pos);
+        std::swap (other.exhausted, exhausted);
+    }
+
     CachedByteArray byteArray;
     GlobalRef stream;
     int64 pos = 0;
     bool exhausted = false;
 };
 
-std::unique_ptr<InputStream> makeAndroidInputStreamWrapper (jobject stream);
-std::unique_ptr<InputStream> makeAndroidInputStreamWrapper (jobject stream)
+std::unique_ptr<InputStream> makeAndroidInputStreamWrapper (LocalRef<jobject> stream);
+std::unique_ptr<InputStream> makeAndroidInputStreamWrapper (LocalRef<jobject> stream)
 {
     return std::make_unique<AndroidInputStreamWrapper> (stream);
 }
@@ -699,7 +683,7 @@ struct AndroidContentUriInputStream final : public InputStream
 
     AndroidContentUriInputStream& operator= (AndroidContentUriInputStream&& other) noexcept
     {
-        std::swap (*this, other);
+        AndroidContentUriInputStream { std::move (other) }.swap (*this);
         return *this;
     }
 
@@ -771,6 +755,12 @@ private:
         return getPosition() == oldPosition + num;
     }
 
+    void swap (AndroidContentUriInputStream& other) noexcept
+    {
+        std::swap (other.stream, stream);
+        std::swap (other.uri, uri);
+    }
+
     AndroidInputStreamWrapper stream;
     GlobalRef uri;
 };
@@ -827,12 +817,7 @@ String File::getVersion() const
 
 static File getDocumentsDirectory()
 {
-    auto* env = getEnv();
-
-    if (getAndroidSDKVersion() >= 19)
-        return getWellKnownFolder ("DIRECTORY_DOCUMENTS");
-
-    return juceFile (LocalRef<jobject> (env->CallStaticObjectMethod (AndroidEnvironment, AndroidEnvironment.getDataDirectory)));
+    return getWellKnownFolder ("DIRECTORY_DOCUMENTS");
 }
 
 static File getAppDataDir (bool dataDir)
