@@ -158,9 +158,30 @@ public:
 
     void runTest() override
     {
-        constexpr int maximumTimeoutMs {30'000};
+        runBehaviourTestsWithBackgroundThreads<0>();
+        runBehaviourTestsWithBackgroundThreads<16>();
+        runStressTests();
+    }
 
-        beginTest ("Start/stop a timer");
+    template <size_t NumBackgroundThreads>
+    void runBehaviourTestsWithBackgroundThreads()
+    {
+        constexpr int maximumTimeoutMs { 30'000 };
+
+        const auto beginBehaviourTest = [&] (const auto& testName)
+        {
+            beginTest (String (testName) + " (" + String (NumBackgroundThreads) + " background timers)");
+        };
+
+        [[maybe_unused]] std::array<BackgroundTimer, NumBackgroundThreads> backgroundTimers;
+
+        beginBehaviourTest ("Background timer preconditions");
+        {
+            for (auto& t : backgroundTimers)
+                expect (t.isTimerRunning());
+        }
+
+        beginBehaviourTest ("Start/stop a timer");
         {
             WaitableEvent timerFiredOnce;
             WaitableEvent timerFiredTwice;
@@ -189,7 +210,7 @@ public:
             expect (timer.getTimerInterval() == 0);
         }
 
-        beginTest ("Stop a timer from the timer callback");
+        beginBehaviourTest ("Stop a timer from the timer callback");
         {
             WaitableEvent stoppedTimer;
 
@@ -206,7 +227,7 @@ public:
             expect (stoppedTimer.wait (maximumTimeoutMs));
         }
 
-        beginTest ("Restart a timer from the timer callback");
+        beginBehaviourTest ("Restart a timer from the timer callback");
         {
             WaitableEvent restartTimer;
             WaitableEvent timerRestarted;
@@ -246,7 +267,7 @@ public:
             timer.stopTimer();
         }
 
-        beginTest ("Calling stopTimer on a timer, waits for any timer callbacks to finish");
+        beginBehaviourTest ("Calling stopTimer on a timer, waits for any timer callbacks to finish");
         {
             WaitableEvent timerCallbackStarted;
             WaitableEvent stoppingTimer;
@@ -276,13 +297,13 @@ public:
             expect (timerCallbackFinished);
         }
 
-        beginTest ("Calling stopTimer on a timer, waits for any timer callbacks to finish, even if the timer callback calls stopTimer first");
+        beginBehaviourTest ("Calling stopTimer on a timer, waits for any timer callbacks to finish, even if the timer callback calls stopTimer first");
         {
             WaitableEvent stoppedFromInsideTimerCallback;
             WaitableEvent stoppingFromOutsideTimerCallback;
             std::atomic<bool> timerCallbackFinished { false };
 
-            Timer timer {[&]()
+            Timer timer {[&]
             {
                 timer.stopTimer();
                 stoppedFromInsideTimerCallback.signal();
@@ -300,7 +321,7 @@ public:
             expect (timerCallbackFinished);
         }
 
-        beginTest ("Adjusting a timer period from outside the timer callback doesn't cause data races");
+        beginBehaviourTest ("Adjusting a timer period from outside the timer callback doesn't cause data races");
         {
             WaitableEvent timerCallbackStarted;
             WaitableEvent timerRestarted;
@@ -343,7 +364,7 @@ public:
             expect (lastCallbackCount == 2);
         }
 
-        beginTest ("A timer can be restarted externally, after being stopped internally");
+        beginBehaviourTest ("A timer can be restarted externally, after being stopped internally");
         {
             WaitableEvent timerStopped;
             WaitableEvent timerFiredAfterRestart;
@@ -378,7 +399,7 @@ public:
             expect (timerFiredAfterRestart.wait (maximumTimeoutMs));
         }
 
-        beginTest ("Calls to `startTimer` and `getTimerInterval` succeed while a callback is blocked");
+        beginBehaviourTest ("Calls to `startTimer` and `getTimerInterval` succeed while a callback is blocked");
         {
             WaitableEvent timerBlocked;
             WaitableEvent unblockTimer;
@@ -400,32 +421,33 @@ public:
             unblockTimer.signal();
             timer.stopTimer();
         }
+    }
 
+    void runStressTests()
+    {
         beginTest ("Stress test");
         {
-            constexpr auto maxNumTimers { 100 };
+            std::vector<Timer> timers (100);
 
-            std::vector<std::unique_ptr<Timer>> timers;
-            timers.reserve (maxNumTimers);
-
-            for (int i = 0; i < maxNumTimers; ++i)
+            for (auto& timer : timers)
             {
-                auto timer = std::make_unique<Timer> ([]{});
-                timer->startTimer (1);
-
-                if (! timer->isTimerRunning())
-                    break;
-
-                timers.push_back (std::move (timer));
+                timer.startTimer (1);
+                expect (timer.isTimerRunning());
             }
 
-            expect (timers.size() >= 16);
+            for (auto& timer : timers)
+            {
+                timer.stopTimer();
+                expect (! timer.isTimerRunning());
+            }
         }
     }
 
     class Timer final : public HighResolutionTimer
     {
     public:
+        Timer() = default;
+
         explicit Timer (std::function<void()> fn)
             : callback (std::move (fn)) {}
 
@@ -434,7 +456,17 @@ public:
         void hiResTimerCallback() override { callback(); }
 
     private:
-        std::function<void()> callback;
+        std::function<void()> callback = []{};
+    };
+
+    class BackgroundTimer
+    {
+    public:
+        BackgroundTimer() { timer.startTimer (1); }
+        bool isTimerRunning() const { return timer.isTimerRunning(); }
+
+    private:
+        Timer timer { []{} };
     };
 };
 
