@@ -450,21 +450,40 @@ public:
     //==============================================================================
     /** Returns the total width of a string as it would be drawn using this font.
         For a more accurate floating-point result, use getStringWidthFloat().
+
+        This function does not take font fallback into account. If this font doesn't
+        include glyphs to represent all characters in the string, then the width
+        will be computed as though those characters were replaced with the "glyph not
+        found" character.
+
+        If you are trying to find the amount of space required to display a given string,
+        you'll get more accurate results by actually measuring the results of whichever
+        text layout engine (e.g. GlyphArrangement, TextLayout) you'll use when displaying
+        the string.
+
+        @see TextLayout::getStringWidth(), GlyphArrangement::getStringWidthInt()
     */
+    [[deprecated ("Use GlyphArrangement or TextLayout to compute text layouts")]]
     int getStringWidth (const String& text) const;
 
     /** Returns the total width of a string as it would be drawn using this font.
         @see getStringWidth
+
+        This function does not take font fallback into account. If this font doesn't
+        include glyphs to represent all characters in the string, then the width
+        will be computed as though those characters were replaced with the "glyph not
+        found" character.
+
+        If you are trying to find the amount of space required to display a given string,
+        you'll get more accurate results by actually measuring the results of whichever
+        text layout engine (e.g. GlyphArrangement, TextLayout) you'll use when displaying
+        the string.
+
+        @see TextLayout::getStringWidth(), GlyphArrangement::getStringWidth()
     */
+    [[deprecated ("Use GlyphArrangement or TextLayout to compute text layouts")]]
     float getStringWidthFloat (const String& text) const;
 
-    /** Returns the series of glyph numbers and their x offsets needed to represent a string.
-
-        An extra x offset is added at the end of the run, to indicate where the right hand
-        edge of the last character is.
-    */
-    void getGlyphPositions (const String& text, Array<int>& glyphs, Array<float>& xOffsets) const;
-
     //==============================================================================
     /** Returns the main typeface used by this font.
 
