@@ -1,24 +1,33 @@
 /*
   ==============================================================================
 
-   This file is part of the JUCE library.
-   Copyright (c) 2022 - Raw Material Software Limited
+   This file is part of the JUCE framework.
+   Copyright (c) Raw Material Software Limited
 
-   JUCE is an open source library subject to commercial or open-source
+   JUCE is an open source framework subject to commercial or open source
    licensing.
 
-   By using JUCE, you agree to the terms of both the JUCE 7 End-User License
-   Agreement and JUCE Privacy Policy.
+   By downloading, installing, or using the JUCE framework, or combining the
+   JUCE framework with any other source code, object code, content or any other
+   copyrightable work, you agree to the terms of the JUCE End User Licence
+   Agreement, and all incorporated terms including the JUCE Privacy Policy and
+   the JUCE Website Terms of Service, as applicable, which will bind you. If you
+   do not agree to the terms of these agreements, we will not license the JUCE
+   framework to you, and you must discontinue the installation or download
+   process and cease use of the JUCE framework.
 
-   End User License Agreement: www.juce.com/juce-7-licence
-   Privacy Policy: www.juce.com/juce-privacy-policy
+   JUCE End User Licence Agreement: https://juce.com/legal/juce-8-licence/
+   JUCE Privacy Policy: https://juce.com/juce-privacy-policy
+   JUCE Website Terms of Service: https://juce.com/juce-website-terms-of-service/
 
-   Or: You may also use this code under the terms of the GPL v3 (see
-   www.gnu.org/licenses).
+   Or:
 
-   JUCE IS PROVIDED "AS IS" WITHOUT ANY WARRANTY, AND ALL WARRANTIES, WHETHER
-   EXPRESSED OR IMPLIED, INCLUDING MERCHANTABILITY AND FITNESS FOR PURPOSE, ARE
-   DISCLAIMED.
+   You may also use this code under the terms of the AGPLv3:
+   https://www.gnu.org/licenses/agpl-3.0.en.html
+
+   THE JUCE FRAMEWORK IS PROVIDED "AS IS" WITHOUT ANY WARRANTY, AND ALL
+   WARRANTIES, WHETHER EXPRESSED OR IMPLIED, INCLUDING WARRANTY OF
+   MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, ARE DISCLAIMED.
 
   ==============================================================================
 */
@@ -324,8 +333,8 @@ public:
     }
 
     /** Returns a rectangle which is the same as this one moved by a given amount. */
-    Rectangle translated (ValueType deltaX,
-                          ValueType deltaY) const noexcept
+    [[nodiscard]] Rectangle translated (ValueType deltaX,
+                                        ValueType deltaY) const noexcept
     {
         return { pos.x + deltaX, pos.y + deltaY, w, h };
     }
@@ -448,8 +457,8 @@ public:
         Effectively, the rectangle returned is (x - deltaX, y - deltaY, w + deltaX * 2, h + deltaY * 2).
         @see expand, reduce, reduced
     */
-    Rectangle expanded (ValueType deltaX,
-                        ValueType deltaY) const noexcept
+    [[nodiscard]] Rectangle expanded (ValueType deltaX,
+                                      ValueType deltaY) const noexcept
     {
         auto nw = jmax (ValueType(), w + deltaX * 2);
         auto nh = jmax (ValueType(), h + deltaY * 2);
@@ -461,7 +470,7 @@ public:
         Effectively, the rectangle returned is (x - delta, y - delta, w + delta * 2, h + delta * 2).
         @see expand, reduce, reduced
     */
-    Rectangle expanded (ValueType delta) const noexcept
+    [[nodiscard]] Rectangle expanded (ValueType delta) const noexcept
     {
         return expanded (delta, delta);
     }
@@ -482,8 +491,8 @@ public:
         Effectively, the rectangle returned is (x + deltaX, y + deltaY, w - deltaX * 2, h - deltaY * 2).
         @see reduce, expand, expanded
     */
-    Rectangle reduced (ValueType deltaX,
-                       ValueType deltaY) const noexcept
+    [[nodiscard]] Rectangle reduced (ValueType deltaX,
+                                     ValueType deltaY) const noexcept
     {
         return expanded (-deltaX, -deltaY);
     }
@@ -493,7 +502,7 @@ public:
         Effectively, the rectangle returned is (x + delta, y + delta, w - delta * 2, h - delta * 2).
         @see reduce, expand, expanded
     */
-    Rectangle reduced (ValueType delta) const noexcept
+    [[nodiscard]] Rectangle reduced (ValueType delta) const noexcept
     {
         return reduced (delta, delta);
     }
@@ -613,10 +622,14 @@ public:
 
     //==============================================================================
     /** Returns true if the two rectangles are identical. */
-    bool operator== (const Rectangle& other) const noexcept     { return pos == other.pos && w == other.w && h == other.h; }
+    bool operator== (const Rectangle& other) const noexcept
+    {
+        const auto tie = [] (const Rectangle& r) { return std::tie (r.pos, r.w, r.h); };
+        return tie (*this) == tie (other);
+    }
 
     /** Returns true if the two rectangles are not identical. */
-    bool operator!= (const Rectangle& other) const noexcept     { return pos != other.pos || w != other.w || h != other.h; }
+    bool operator!= (const Rectangle& other) const noexcept     { return ! operator== (other); }
 
     /** Returns true if this coordinate is inside the rectangle. */
     bool contains (ValueType xCoord, ValueType yCoord) const noexcept
@@ -737,7 +750,7 @@ public:
     */
     bool enlargeIfAdjacent (Rectangle other) noexcept
     {
-        if (pos.x == other.pos.x && getRight() == other.getRight()
+        if (exactlyEqual (pos.x, other.pos.x) && exactlyEqual (getRight(), other.getRight())
              && (other.getBottom() >= pos.y && other.pos.y <= getBottom()))
         {
             auto newY = jmin (pos.y, other.pos.y);
@@ -746,7 +759,7 @@ public:
             return true;
         }
 
-        if (pos.y == other.pos.y && getBottom() == other.getBottom()
+        if (exactlyEqual (pos.y, other.pos.y) && exactlyEqual (getBottom(), other.getBottom())
              && (other.getRight() >= pos.x && other.pos.x <= getRight()))
         {
             auto newX = jmin (pos.x, other.pos.x);
@@ -811,7 +824,7 @@ public:
 
         This should only be used on floating point rectangles.
     */
-    Rectangle transformedBy (const AffineTransform& transform) const noexcept
+    [[nodiscard]] Rectangle transformedBy (const AffineTransform& transform) const noexcept
     {
         using FloatType = TypeHelpers::SmallestFloatType<ValueType>;
 
@@ -835,7 +848,7 @@ public:
 
     /** Returns the smallest integer-aligned rectangle that completely contains this one.
         This is only relevant for floating-point rectangles, of course.
-        @see toFloat(), toNearestInt(), toNearestIntEdges()
+        @see toFloat(), toNearestInt(), toNearestIntEdges(), getLargestIntegerWithin()
     */
     Rectangle<int> getSmallestIntegerContainer() const noexcept
     {
@@ -845,6 +858,22 @@ public:
                                                    detail::ceilAsInt  (pos.y + h));
     }
 
+    /** Returns the largest integer-aligned rectangle that is completely contained by this one.
+        Returns an empty rectangle, outside the original rectangle, if no integer-aligned rectangle
+        is contained by this one.
+        This is only relevant for floating-point rectangles, of course.
+        @see toFloat(), toNearestInt(), toNearestIntEdges(), getSmallestIntegerContainer()
+    */
+    Rectangle<int> getLargestIntegerWithin() const noexcept
+    {
+        const auto l = detail::ceilAsInt  (pos.x);
+        const auto t = detail::ceilAsInt  (pos.y);
+        const auto r = detail::floorAsInt (pos.x + w);
+        const auto b = detail::floorAsInt (pos.y + h);
+
+        return { l, t, jmax (0, r - l), jmax (0, b - t) };
+    }
+
     /** Casts this rectangle to a Rectangle<int>.
         This uses roundToInt to snap x, y, width and height to the nearest integer (losing precision).
         If the rectangle already uses integers, this will simply return a copy.
