@@ -176,15 +176,13 @@ public:
         return {};
     }
 
-    JUCE_DECLARE_SINGLETON (MemoryFontCache, true)
+    JUCE_DECLARE_SINGLETON_INLINE (MemoryFontCache, true)
 
 private:
     std::map<Key, Value> cache;
     mutable std::mutex mutex;
 };
 
-JUCE_IMPLEMENT_SINGLETON (MemoryFontCache)
-
 StringArray Font::findAllTypefaceNames()
 {
     auto results = [&]
