@@ -617,6 +617,11 @@ void ComponentPeer::forceDisplayUpdate()
     Desktop::getInstance().displays->refresh();
 }
 
+void ComponentPeer::callVBlankListeners (double timestampSec)
+{
+    vBlankListeners.call ([timestampSec] (auto& l) { l.onVBlank (timestampSec); });
+}
+
 void ComponentPeer::globalFocusChanged ([[maybe_unused]] Component* comp)
 {
     refreshTextInputTarget();
