@@ -35,7 +35,9 @@
 namespace juce
 {
 
-JUCE_BEGIN_IGNORE_WARNINGS_GCC_LIKE ("-Wdeprecated-declarations")
+#define JUCE_PUSH_NOTIFICATIONS_IMPL 1
+
+JUCE_BEGIN_IGNORE_DEPRECATION_WARNINGS
 
 namespace PushNotificationsDelegateDetailsOsx
 {
@@ -343,9 +345,9 @@ private:
 bool PushNotifications::Notification::isValid() const noexcept { return true; }
 
 //==============================================================================
-struct PushNotifications::Pimpl : private PushNotificationsDelegate
+struct PushNotifications::Impl : private PushNotificationsDelegate
 {
-    Pimpl (PushNotifications& p)
+    explicit Impl (PushNotifications& p)
         : owner (p)
     {
     }
@@ -534,6 +536,6 @@ private:
     PushNotifications::Settings settings;
 };
 
-JUCE_END_IGNORE_WARNINGS_GCC_LIKE
+JUCE_END_IGNORE_DEPRECATION_WARNINGS
 
 } // namespace juce
