@@ -1137,11 +1137,11 @@ private:
         // Using the non-deprecated webkit_javascript_result_get_js_value() functions seems easier
         // but returned values fail the JS_IS_VALUE() internal assertion. The example code from the
         // documentation doesn't seem to work either.
-        JUCE_BEGIN_IGNORE_WARNINGS_GCC_LIKE ("-Wdeprecated-declarations")
+        JUCE_BEGIN_IGNORE_DEPRECATION_WARNINGS
         WebKitJavascriptResultUniquePtr jsResult { wk.juce_webkit_web_view_run_javascript_finish (owner->webview,
                                                                                                      result,
                                                                                                      &error) };
-        JUCE_END_IGNORE_WARNINGS_GCC_LIKE
+        JUCE_END_IGNORE_DEPRECATION_WARNINGS
 
         if (jsResult == nullptr)
         {
