@@ -1,24 +1,33 @@
 /*
   ==============================================================================
 
-   This file is part of the JUCE library.
-   Copyright (c) 2022 - Raw Material Software Limited
+   This file is part of the JUCE framework.
+   Copyright (c) Raw Material Software Limited
 
-   JUCE is an open source library subject to commercial or open-source
+   JUCE is an open source framework subject to commercial or open source
    licensing.
 
-   By using JUCE, you agree to the terms of both the JUCE 7 End-User License
-   Agreement and JUCE Privacy Policy.
+   By downloading, installing, or using the JUCE framework, or combining the
+   JUCE framework with any other source code, object code, content or any other
+   copyrightable work, you agree to the terms of the JUCE End User Licence
+   Agreement, and all incorporated terms including the JUCE Privacy Policy and
+   the JUCE Website Terms of Service, as applicable, which will bind you. If you
+   do not agree to the terms of these agreements, we will not license the JUCE
+   framework to you, and you must discontinue the installation or download
+   process and cease use of the JUCE framework.
 
-   End User License Agreement: www.juce.com/juce-7-licence
-   Privacy Policy: www.juce.com/juce-privacy-policy
+   JUCE End User Licence Agreement: https://juce.com/legal/juce-8-licence/
+   JUCE Privacy Policy: https://juce.com/juce-privacy-policy
+   JUCE Website Terms of Service: https://juce.com/juce-website-terms-of-service/
 
-   Or: You may also use this code under the terms of the GPL v3 (see
-   www.gnu.org/licenses).
+   Or:
 
-   JUCE IS PROVIDED "AS IS" WITHOUT ANY WARRANTY, AND ALL WARRANTIES, WHETHER
-   EXPRESSED OR IMPLIED, INCLUDING MERCHANTABILITY AND FITNESS FOR PURPOSE, ARE
-   DISCLAIMED.
+   You may also use this code under the terms of the AGPLv3:
+   https://www.gnu.org/licenses/agpl-3.0.en.html
+
+   THE JUCE FRAMEWORK IS PROVIDED "AS IS" WITHOUT ANY WARRANTY, AND ALL
+   WARRANTIES, WHETHER EXPRESSED OR IMPLIED, INCLUDING WARRANTY OF
+   MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, ARE DISCLAIMED.
 
   ==============================================================================
 */
@@ -125,7 +134,7 @@ struct KeyFileUtils
                 xml = parseXML (mb.toString());
         }
 
-        return xml != nullptr ? *xml : XmlElement("key");
+        return xml != nullptr ? *xml : XmlElement ("key");
     }
 
     static XmlElement getXmlFromKeyFile (String keyFileText, RSAKey rsaPublicKey)
@@ -319,12 +328,15 @@ String OnlineUnlockStatus::MachineIDUtilities::getUniqueMachineID()
     return getEncodedIDString (SystemStats::getUniqueDeviceID());
 }
 
-JUCE_BEGIN_IGNORE_WARNINGS_GCC_LIKE ("-Wdeprecated-declarations")
-JUCE_BEGIN_IGNORE_WARNINGS_MSVC (4996)
+JUCE_BEGIN_IGNORE_DEPRECATION_WARNINGS
 
 StringArray OnlineUnlockStatus::MachineIDUtilities::getLocalMachineIDs()
 {
-    auto identifiers = SystemStats::getDeviceIdentifiers();
+    auto flags = SystemStats::MachineIdFlags::macAddresses
+               | SystemStats::MachineIdFlags::fileSystemId
+               | SystemStats::MachineIdFlags::legacyUniqueId
+               | SystemStats::MachineIdFlags::uniqueId;
+    auto identifiers = SystemStats::getMachineIdentifiers (flags);
 
     for (auto& identifier : identifiers)
         identifier = getEncodedIDString (identifier);
@@ -337,8 +349,7 @@ StringArray OnlineUnlockStatus::getLocalMachineIDs()
     return MachineIDUtilities::getLocalMachineIDs();
 }
 
-JUCE_END_IGNORE_WARNINGS_GCC_LIKE
-JUCE_END_IGNORE_WARNINGS_MSVC
+JUCE_END_IGNORE_DEPRECATION_WARNINGS
 
 void OnlineUnlockStatus::userCancelled()
 {
@@ -354,39 +365,45 @@ String OnlineUnlockStatus::getUserEmail() const
     return status[userNameProp].toString();
 }
 
-bool OnlineUnlockStatus::applyKeyFile (String keyFileContent)
+Result OnlineUnlockStatus::applyKeyFile (const String& keyFileContent)
 {
     KeyFileUtils::KeyFileData data;
     data = KeyFileUtils::getDataFromKeyFile (KeyFileUtils::getXmlFromKeyFile (keyFileContent, getPublicKey()));
 
-    if (data.licensee.isNotEmpty() && data.email.isNotEmpty() && doesProductIDMatch (data.appID))
+    if (data.licensee.isEmpty() || data.email.isEmpty())
+        return Result::fail (LicenseResult::badCredentials);
+
+    if (! doesProductIDMatch (data.appID))
+        return Result::fail (LicenseResult::badProductID);
+
+    if (MachineIDUtilities::getUniqueMachineID().isEmpty())
+        return Result::fail (LicenseResult::notReady);
+
+    setUserEmail (data.email);
+    status.setProperty (keyfileDataProp, keyFileContent, nullptr);
+    status.removeProperty (data.keyFileExpires ? expiryTimeProp : unlockedProp, nullptr);
+
+    var actualResult (0), dummyResult (1.0);
+    var v (machineNumberAllowed (data.machineNumbers, getLocalMachineIDs()));
+    actualResult.swapWith (v);
+    v = machineNumberAllowed (StringArray ("01"), getLocalMachineIDs());
+    dummyResult.swapWith (v);
+    jassert (! dummyResult);
+
+    if (data.keyFileExpires)
     {
-        setUserEmail (data.email);
-        status.setProperty (keyfileDataProp, keyFileContent, nullptr);
-        status.removeProperty (data.keyFileExpires ? expiryTimeProp : unlockedProp, nullptr);
-
-        var actualResult (0), dummyResult (1.0);
-        var v (machineNumberAllowed (data.machineNumbers, getLocalMachineIDs()));
-        actualResult.swapWith (v);
-        v = machineNumberAllowed (StringArray ("01"), getLocalMachineIDs());
-        dummyResult.swapWith (v);
-        jassert (! dummyResult);
-
-        if (data.keyFileExpires)
-        {
-            if ((! dummyResult) && actualResult)
-                status.setProperty (expiryTimeProp, data.expiryTime.toMilliseconds(), nullptr);
-
-            return getExpiryTime().toMilliseconds() > 0;
-        }
-
         if ((! dummyResult) && actualResult)
-            status.setProperty (unlockedProp, actualResult, nullptr);
+            status.setProperty (expiryTimeProp, data.expiryTime.toMilliseconds(), nullptr);
 
-        return isUnlocked();
+        return getExpiryTime().toMilliseconds() > 0 ? Result::ok()
+                                                    : Result::fail (LicenseResult::licenseExpired);
     }
 
-    return false;
+    if ((! dummyResult) && actualResult)
+        status.setProperty (unlockedProp, actualResult, nullptr);
+
+    return isUnlocked() ? Result::ok()
+                        : Result::fail (LicenseResult::unlockFailed);
 }
 
 static bool areMajorWebsitesAvailable()
@@ -408,14 +425,22 @@ OnlineUnlockStatus::UnlockResult OnlineUnlockStatus::handleXmlReply (XmlElement
 {
     UnlockResult r;
 
-    if (auto keyNode = xml.getChildByName ("KEY"))
+    r.succeeded = false;
+
+    if (const auto keyNode = xml.getChildByName ("KEY"))
     {
-        const String keyText (keyNode->getAllSubText().trim());
-        r.succeeded = keyText.length() > 10 && applyKeyFile (keyText);
-    }
-    else
-    {
-        r.succeeded = false;
+        if (const auto keyText = keyNode->getAllSubText().trim(); keyText.length() > 10)
+        {
+            const auto keyFileResult = applyKeyFile (keyText);
+
+            if (keyFileResult.failed())
+            {
+                r.errorMessage = keyFileResult.getErrorMessage();
+                return r;
+            }
+
+            r.succeeded = true;
+        }
     }
 
     if (xml.hasTagName ("MESSAGE"))
@@ -443,17 +468,17 @@ OnlineUnlockStatus::UnlockResult OnlineUnlockStatus::handleFailedConnection()
 
 String OnlineUnlockStatus::getMessageForConnectionFailure (bool isInternetConnectionWorking)
 {
-    String message = TRANS("Couldn't connect to XYZ").replace ("XYZ", getWebsiteName()) + "...\n\n";
+    String message = TRANS ("Couldn't connect to XYZ").replace ("XYZ", getWebsiteName()) + "...\n\n";
 
     if (isInternetConnectionWorking)
-        message << TRANS("Your internet connection seems to be OK, but our webserver "
-                         "didn't respond... This is most likely a temporary problem, so try "
-                         "again in a few minutes, but if it persists, please contact us for support!");
+        message << TRANS ("Your internet connection seems to be OK, but our webserver "
+                          "didn't respond... This is most likely a temporary problem, so try "
+                          "again in a few minutes, but if it persists, please contact us for support!");
     else
-        message << TRANS("No internet sites seem to be accessible from your computer.. Before trying again, "
-                         "please check that your network is working correctly, and make sure "
-                         "that any firewall/security software installed on your machine isn't "
-                         "blocking your web connection.");
+        message << TRANS ("No internet sites seem to be accessible from your computer.. Before trying again, "
+                          "please check that your network is working correctly, and make sure "
+                          "that any firewall/security software installed on your machine isn't "
+                          "blocking your web connection.");
 
     return message;
 }
@@ -461,7 +486,7 @@ String OnlineUnlockStatus::getMessageForConnectionFailure (bool isInternetConnec
 String OnlineUnlockStatus::getMessageForUnexpectedReply()
 {
     return TRANS ("Unexpected or corrupted reply from XYZ").replace ("XYZ", getWebsiteName()) + "...\n\n"
-                    + TRANS("Please try again in a few minutes, and contact us for support if this message appears again.");
+                    + TRANS ("Please try again in a few minutes, and contact us for support if this message appears again.");
 }
 
 OnlineUnlockStatus::UnlockResult OnlineUnlockStatus::attemptWebserverUnlock (const String& email,
